==> lam_6.3.2.orig.tar.gz: lam-6.3.2/share/mpi/infogetnth.c <==
/*
 *
 * Copyright 1998-1999, University of Notre Dame.
 * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
 *          and Andrew Lumsdaine
 *
 * This file is part of the Notre Dame LAM implementation of MPI.
 *
 * You should have received a copy of the License Agreement for the
 * Notre Dame LAM implementation of MPI along with the software; see
 * the file LICENSE.  If not, contact Office of Research, University
 * of Notre Dame, Notre Dame, IN 46556.
 *
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 *
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.  
 *
 * Additional copyrights may follow.
 *
 *	Ohio Trollius
 *	Copyright 1997 The Ohio State University
 *	NJN
 *
 *	$Id: infogetnth.c,v 6.3 1999/05/25 22:08:01 kmeyer1 Exp $
 *
 *	Function:	- get n'th key in info object
 *	Accepts:	- info
 *			- n
 *			- key (out)
 *	Returns:	- MPI_SUCCESS or error code
 */

#include <string.h>

#include <all_list.h>
#include <blktype.h>
#include <mpi.h>
#include <mpisys.h>


int
MPI_Info_get_nthkey(info, n, key)

MPI_Info		info;
int			n;
char			*key;

{
	struct _infoent	*p;			/* key/value pair */
	
	lam_initerr_m();
	lam_setfunc_m(BLKMPIINFOGETNTHKEY);

	if (info == 0 || n >= al_count(info->info_list) || key == 0) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIINFOGETNTHKEY,
					lam_mkerr(MPI_ERR_ARG, 0)));
	}

	for (p = al_top(info->info_list); n > 0; n--) {
		p = al_next(info->info_list, p);
	}

	strcpy(key, p->ie_key);

	lam_resetfunc_m(BLKMPIINFOGETNTHKEY);
	return(MPI_SUCCESS);
}

==> lam-6.5.1.tar.gz: lam-6.5.1/share/mpi/infogetnth.c <==
/*
 * Copyright 1998-2001, University of Notre Dame.
 * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
 *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
 * 
 * This file is part of the Notre Dame LAM implementation of MPI.
 * 
 * You should have received a copy of the License Agreement for the Notre
 * Dame LAM implementation of MPI along with the software; see the file
 * LICENSE.  If not, contact Office of Research, University of Notre
 * Dame, Notre Dame, IN 46556.
 * 
 * Permission to modify the code and to distribute modified code is
 * granted, provided the text of this NOTICE is retained, a notice that
 * the code was modified is included with the above COPYRIGHT NOTICE and
 * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
 * file is distributed with the modified code.
 * 
 * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
 * By way of example, but not limitation, Licensor MAKES NO
 * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
 * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
 * OR OTHER RIGHTS.
 * 
 * Additional copyrights may follow.
 * 
 *	Ohio Trollius
 *	Copyright 1997 The Ohio State University
 *	NJN
 *
 *	$Id: infogetnth.c,v 6.5 2001/02/03 20:24:38 jsquyres Exp $
 *
 *	Function:	- get n'th key in info object
 *	Accepts:	- info
 *			- n
 *			- key (out)
 *	Returns:	- MPI_SUCCESS or error code
 */

#include <string.h>

#include <all_list.h>
#include <blktype.h>
#include <mpi.h>
#include <mpisys.h>


/*@
  MPI_Info_get_nthkey - Get a key indexed by integer from an 'MPI_Info' object

int MPI_Info_get_nthkey(MPI_Info info, int n, char *key)

Input Parameters:
+ info - info object (handle)
- n - index of key to retrieve (integer)

Output Parameter:
. key - character string of at least 'MPI_MAX_INFO_KEY' characters

.N fortran

.N Errors
.N MPI_SUCCESS
.N MPI_ERR_ARG

.N WEB
@*/
int MPI_Info_get_nthkey(MPI_Info info, int n, char *key)
{
	struct _infoent	*p;			/* key/value pair */
	
	lam_initerr_m();
	lam_setfunc_m(BLKMPIINFOGETNTHKEY);

	if (info == 0 || n >= al_count(info->info_list) || key == 0) {
		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIINFOGETNTHKEY,
					lam_mkerr(MPI_ERR_ARG, 0)));
	}

	for (p = al_top(info->info_list); n > 0; n--) {
		p = al_next(info->info_list, p);
	}

	strcpy(key, p->ie_key);

	lam_resetfunc_m(BLKMPIINFOGETNTHKEY);
	return(MPI_SUCCESS);
}
